/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.management.task.download.jetty.server;

import java.net.Inet4Address;
import java.net.InetAddress;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;

/**
 * This class is used to store only the SOAP server related configuration values.
 * @author Christophe HAMERLING - EBM WebSourcing
 */
public class ServerConfig {

    /**
     * The port used for incoming SOAP requests
     */
    private int port = Constants.HttpServer.DEFAULT_HTTP_PORT;

    /**
     * The current interfaces which can be use for incoming listening
     */
    private List<InetAddress> addresses;

    /**
     * The host
     */
    private String host = Constants.HttpServer.DEFAULT_HTTP_HOST;

    /**
     * Restrict access to a particular network interface
     */
    private boolean restrict = false;

    /**
     * Creates a new instance of {@link ServerConfig}
     * 
     */
    public ServerConfig() {
        this.addresses = new ArrayList<InetAddress>();
    }

    /**
     * @return the port
     */
    public int getPort() {
        return this.port;
    }

    /**
     * @param port
     *            the port to set
     */
    public void setPort(final int port) {
        this.port = port;
    }

    /**
     * @param ia
     *            the network interface to set
     */
    protected void addAddress(final InetAddress ia) {
        this.addresses.add(ia);
    }

    /**
     * Add all the {@link InetAddress}
     * 
     * @param addresses
     */
    protected void addAddresses(final Set<Inet4Address> addresses) {
        this.addresses.addAll(addresses);
    }

    /**
     * 
     * @return
     */
    public String getHost() {
        /*
         * if (this.host == null) { this.host = this.buildHost(); }
         */
        return this.host;
    }

    /**
     * @return the restrict
     */
    public boolean isRestrict() {
        return restrict;
    }

    /**
     * @param restrict
     *            the restrict to set
     */
    public void setRestrict(boolean restrict) {
        this.restrict = restrict;
    }
}
